"""
$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/toboso/lib/local_ui.py $
$Id: local_ui.py 26293 2005-03-07 15:10:52Z dbinger $
"""

from sets import ImmutableSet
from dulcinea.ui.user.util import format_personal_profile_links
from dulcinea.ui.user.util import format_user_profile
from dulcinea.ui.user.util import format_user_profile_links, format_user
from dulcinea.ui.util import format_date, format_date_time
from toboso.ui.standard import header, footer

format_login_agreement = lambda : None # No login agreement

FEEDBACK_DOMAIN = 'yourdomain.here'

VALID_FEEDBACK_ADDRESSES = ImmutableSet(['boss'])
