#!/usr/bin/env python

"""$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/toboso/setup.py $
$Id: setup.py 26294 2005-03-07 17:17:05Z dbinger $

Setup script for Toboso
"""

from distutils import core
from distutils.extension import Extension
from quixote.qx_distutils import qx_build_py

kw = {'name': "Toboso",
      'version': "0.6",
      'description': ("A Dulcinea demonstration application."),
      'author': "CNRI",
      'author_email': "mems-dev@mems-exchange.org",
      'url': "http://www.mems-exchange.org/software/toboso/",
      'license': "see LICENSE.txt",
      'package_dir': {'toboso':'lib'},
      'packages': ['toboso',  'toboso.ui'],
      'cmdclass': {'build_py': qx_build_py},
     }

# If we're running Python 2.3, add extra information
if hasattr(core, 'setup_keywords'):
    if 'classifiers' in core.setup_keywords:
        kw['classifiers'] = ['Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'Operating System :: Unix',
          'Topic :: Software Development :: Libraries',
          ]
    if 'download_url' in core.setup_keywords:
        kw['download_url'] = ('http://www.mems-exchange.org/software/files'
                              '/toboso/Toboso-%s.tar.gz' % kw['version'])

core.setup(**kw)
